pub struct ShredStreamClient { /* private fields */ }Expand description
High-level multi-source shred subscription client.
Implementations
Sourceimpl ShredStreamClient
impl ShredStreamClient
Sourcepub async fn new(udp_bind: impl Into<String>) -> AnyResult<Self>
pub async fn new(udp_bind: impl Into<String>) -> AnyResult<Self>
Create a client bound to a raw UDP address, for example 0.0.0.0:8001.
pub async fn new_with_decode_mode( decode_mode: ShredDecodeMode, ) -> AnyResult<Self>
pub async fn new_jito_grpc(endpoint: impl Into<String>) -> AnyResult<Self>
pub async fn new_with_config(config: ShredStreamConfig) -> AnyResult<Self>
Sourcepub async fn subscribe(&self) -> AnyResult<Arc<ArrayQueue<DexEvent>>>
pub async fn subscribe(&self) -> AnyResult<Arc<ArrayQueue<DexEvent>>>
Subscribe to all supported DEX events and return a lock-free queue.
All supported decode modes feed the same parser:
source -> Entry -> VersionedTransaction -> DexEvent.
Sourcepub async fn subscribe_with_filter(
&self,
event_type_filter: Option<EventTypeFilter>,
) -> AnyResult<Arc<ArrayQueue<DexEvent>>>
pub async fn subscribe_with_filter( &self, event_type_filter: Option<EventTypeFilter>, ) -> AnyResult<Arc<ArrayQueue<DexEvent>>>
Subscribe to DEX events with parser-side event filtering.
Sourcepub async fn subscribe_callback<F>(&self, callback: F) -> AnyResult<()>
pub async fn subscribe_callback<F>(&self, callback: F) -> AnyResult<()>
Lowest-latency built-in DEX path: event callback runs in the source receive task.
Sourcepub async fn subscribe_with_filter_callback<F>(
&self,
event_type_filter: Option<EventTypeFilter>,
callback: F,
) -> AnyResult<()>
pub async fn subscribe_with_filter_callback<F>( &self, event_type_filter: Option<EventTypeFilter>, callback: F, ) -> AnyResult<()>
Lowest-latency built-in DEX path with event filtering.
Sourcepub async fn subscribe_pumpfun(
&self,
parser_config: PumpfunParserConfig,
) -> AnyResult<Arc<ArrayQueue<PumpfunEvent>>>
pub async fn subscribe_pumpfun( &self, parser_config: PumpfunParserConfig, ) -> AnyResult<Arc<ArrayQueue<PumpfunEvent>>>
Compatibility convenience for the legacy PumpFun/Bonk parser.
Sourcepub async fn subscribe_pumpfun_callback<F>(
&self,
parser_config: PumpfunParserConfig,
callback: F,
) -> AnyResult<()>
pub async fn subscribe_pumpfun_callback<F>( &self, parser_config: PumpfunParserConfig, callback: F, ) -> AnyResult<()>
Lowest-latency built-in PumpFun/Bonk path: event callback runs in the source receive task.
Sourcepub async fn subscribe_with_parser<P>(
&self,
parser: P,
) -> AnyResult<Arc<ArrayQueue<P::Event>>>
pub async fn subscribe_with_parser<P>( &self, parser: P, ) -> AnyResult<Arc<ArrayQueue<P::Event>>>
Subscribe with a custom parser and return a queue of parser events.
Sourcepub async fn subscribe_with_parser_callback<P, F>(
&self,
parser: P,
callback: F,
) -> AnyResult<()>
pub async fn subscribe_with_parser_callback<P, F>( &self, parser: P, callback: F, ) -> AnyResult<()>
Subscribe with a custom parser and direct event callback.
pub async fn stop(&self)